@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "emacsql" "4.3.5"
+(define-package "emacsql" "20251116.1655"
   "High-level SQL database front-end."
   '((emacs "26.1"))
   :url "https://github.com/magit/emacsql"
-  :commit "6ef7473248fce048c7daa00c3b2ae75af987c89c"
-  :revdesc "v4.3.5-0-g6ef7473248fc"
+  :commit "e1908de2cf2c7b77798ef6645d514dded1d7f8a4"
+  :revdesc "e1908de2cf2c"
   :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
   :maintainers '(("Jonas Bernoulli" . "emacs.emacsql@jonas.bernoulli.dev")))
